@@ -2,10 +2,7 @@ package Game::Battleship;
 our $AUTHORITY = 'cpan:GENE';
 # ABSTRACT: "You sunk my battleship!"
 
-use strict;
-use warnings;
-
-our $VERSION = '0.06';
+our $VERSION = '0.0601';
 
 use Carp;
 use Game::Battleship::Player;
@@ -79,10 +76,10 @@ sub player {
 
     # Step through each player...
     for (keys %{ $self->{players} }) {
-        # Are we looking at the same player name, key or number?
+        # Are we looking at the same player by name, key or id?
         if( $_ eq $name ||
-            $self->{players}{$_}{name} eq $name ||
-            $self->{players}{$_}{id} eq $name
+            $self->{players}{$_}->name eq $name ||
+            $self->{players}{$_}->id eq $name
         ) {
             # Set the player object to return.
             $player = $self->{players}{$_};
@@ -102,12 +99,12 @@ sub play {
     while (not $winner) {
         # Take a turn per live player.
         for my $player (values %{ $self->{players} }) {
-            next unless $player->{life};
+            next unless $player->life;
 
             # Strike each opponent.
             for my $opponent (values %{ $self->{players} }) {
-                next if $opponent->{name} eq $player->{name} ||
-                    !$opponent->{life};
+                next if $opponent->name eq $player->name ||
+                    !$opponent->life;
 
                 my $res = -1;  # "duplicate strike" flag.
                 while ($res == -1) {
@@ -120,7 +117,7 @@ sub play {
         }
 
         # Do we have a winner?
-        my @alive = grep { $self->{players}{$_}{life} } keys %{ $self->{players} };
+        my @alive = grep { $self->{players}{$_}->life } keys %{ $self->{players} };
         $winner = @alive == 1 ? shift @alive : undef;
     }
 
@@ -158,7 +155,7 @@ Game::Battleship - "You sunk my battleship!"
 
 =head1 VERSION
 
-version 0.06
+version 0.0601
 
 =head1 SYNOPSIS
 
