@@ -1,10 +1,8 @@
 package Game::Battleship::Craft;
-$Game::Battleship::Craft::VERSION = '0.06';
+$Game::Battleship::Craft::VERSION = '0.0601';
 our $AUTHORITY = 'cpan:GENE';
-use strict;
-use warnings;
-use Carp;
 
+use Carp;
 use Moo;
 use Types::Standard qw( ArrayRef Int Num Str );
 
@@ -46,7 +44,7 @@ sub hit {
     # Tally the hit.
     $self->{hits}++;
     # Hand back the remainder of the craft's value.
-    return $self->{points} - $self->{hits};
+    return $self->points - $self->hits;
 }
 
 1;
@@ -63,7 +61,7 @@ Game::Battleship::Craft
 
 =head1 VERSION
 
-version 0.06
+version 0.0601
 
 =head1 SYNOPSIS
 
